# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## Unreleased
### Added
### Changed
### Fixed

## [0.2.4] - 2025-26-07
### Added
- Test aegis-ai publishing to pypi

## [0.2.3] - 2025-26-07
### Added
- Initial aegis-ai development release

